// Copyright 2009 the Sputnik authors.  All rights reserved.
// This code is governed by the BSD license found in the LICENSE file.

/**
 * DecimalLiteral :: ExponentPart is incorrect
 *
 * @path ch07/7.8/7.8.3/S7.8.3_A4.1_T2.js
 * @description ExponentPart :: E DecimalDigits
 * @negative
 */

//CHECK#1
E1

